@@ -41,7 +41,7 @@ namespace Digikam
 
 class DIGIKAM_EXPORT FirstRunWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     
