@@ -73,8 +73,8 @@ RatingWidget::RatingWidget(TQWidget* parent)
 
     slotThemeChanged();
 
-    connect(ThemeEngine::instance(), TQT_SIGNAL(signalThemeChanged()),
-            this, TQT_SLOT(slotThemeChanged()));
+    connect(ThemeEngine::instance(), TQ_SIGNAL(signalThemeChanged()),
+            this, TQ_SLOT(slotThemeChanged()));
 }
 
 RatingWidget::~RatingWidget()
