@@ -43,7 +43,7 @@ class DImg;
 
 class DIGIKAM_EXPORT RAWLoader : public KDcrawIface::KDcraw, public DImgLoader
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
