@@ -35,12 +35,12 @@
 
 // KDE includes.
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 #include <kuser.h>
-#include <kapplication.h>
-#include <kglobalsettings.h>
+#include <tdeapplication.h>
+#include <tdeglobalsettings.h>
 
 // Local includes.
 
@@ -88,8 +88,8 @@ ThemeEngine* ThemeEngine::instance()
 ThemeEngine::ThemeEngine()
 {
     m_instance = this;
-    KGlobal::dirs()->addResourceType("themes",
-                                     KGlobal::dirs()->kde_default("data")
+    TDEGlobal::dirs()->addResourceType("themes",
+                                     TDEGlobal::dirs()->kde_default("data")
                                      + "digikam/themes");
 
     d = new ThemeEnginePriv;
@@ -195,7 +195,7 @@ void ThemeEngine::scanThemes()
     d->themeDict.clear();
     d->currTheme = 0;
 
-    TQStringList themes = KGlobal::dirs()->findAllResources( "themes", TQString(), false, true );
+    TQStringList themes = TDEGlobal::dirs()->findAllResources( "themes", TQString(), false, true );
 
     for (TQStringList::iterator it=themes.begin(); it != themes.end();
          ++it)
@@ -248,7 +248,7 @@ void ThemeEngine::setCurrentTheme(const TQString& name)
 
     changePalette();
 
-    TQTimer::singleShot(0, this, TQT_SIGNAL(signalThemeChanged()));
+    TQTimer::singleShot(0, this, TQ_SIGNAL(signalThemeChanged()));
 }
 
 void ThemeEngine::setCurrentTheme(const Theme& theme, const TQString& name, bool loadFromDisk)
@@ -271,7 +271,7 @@ void ThemeEngine::setCurrentTheme(const Theme& theme, const TQString& name, bool
 
     changePalette();
 
-    TQTimer::singleShot(0, this, TQT_SIGNAL(signalThemeChanged()));
+    TQTimer::singleShot(0, this, TQ_SIGNAL(signalThemeChanged()));
 }
 
 void ThemeEngine::changePalette()
