@@ -41,7 +41,7 @@ class CameraFolderItem;
 
 class CameraFolderDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
